pub struct Account {Show 14 fields
pub id: String,
pub username: String,
pub display_name: String,
pub acct: String,
pub url: String,
pub followers_count: u64,
pub following_count: u64,
pub statuses_count: u64,
pub note: String,
pub avatar: String,
pub header: String,
pub locked: bool,
pub bot: bool,
pub created_at: String,
}Expand description
Represents a user account on Mastodon.
Fields
id: StringThe local ID of the account.
username: StringThe username of the account, not including domain.
display_name: StringThe profile’s display name.
acct: StringThe unique identifier of the account, usually username@domain.
For local users, it may just be the username.
url: StringThe URL of the user’s profile.
followers_count: u64The number of followers for the account.
following_count: u64The number of accounts this user is following.
statuses_count: u64The number of statuses (posts) the user has created.
note: StringThe user’s bio (note).
avatar: StringURL of the user’s avatar image.
header: StringURL of the user’s header image.
locked: boolWhether the account is locked and requires follow requests.
bot: boolWhether the account is a bot.
created_at: StringThe time the account was created (ISO 8601).